unit RsDefines;

interface

uses Classes, Messages, SysUtils;


type

  TItemType =  (itIdenty, itProcess, itRegServer, itFile, itRegistryItem, itMessage);
  TRiskType = (rtUnknown, rtNormal, rtHighRisk, rtRogueSoft);
  TCleanMethod = (cmUnknown, cmDelete, cmUnRegsvr, cmModify, cmKill, cmShowHint);


  pCleanItem = ^TCleanItem;
  TCleanItem = packed record
    ItemType: TItemType;
    Name: string;
    Hint: string;
    OldValue: string;
    NewValue: string;
    Method: TCleanMethod;
    Found: boolean;
  end;

  pCleanInfo = ^TCleanInfo;
  TCleanInfo = packed record
    FileName: string;
    Items: TList;
    Identify: string;
    Name: string;
    Desc: string;
    Ver: string;
    Size: Cardinal;
    Author: string;
    Enable: boolean;
    ID: integer;
  end;

  TArrCleanInfo = array of TCleanInfo;

  TFoundItem = (ftNotfound, ftFound, ftFoundPart);
  TMessageType = (mtDetectMessage, mtDetectPercent, mtDetectFinished, mtRogueFound, mtPartFound, mtNoRsFound,
                  mtCleanMessage, mtCleanPercent, mtCleanFinished,
                  mtCleanSuccess, mtCleanFaild);

  ICleanInfo = interface
  ['{EB44EA6D-8619-41CC-9DED-667C2AB7E6E8}']
    procedure OnMessage(const Engine: pCleanInfo; const MsgType: TMessageType; const Param1, Param2: Cardinal);
    procedure OnEngineLoadOK;
    procedure OnLoading(const EngineName: string; const Total, Loaded: Cardinal);
  end;

  IRsCleaner = interface
  ['{9C473C29-52DD-4B1A-AC83-9E93E32C46BF}']
    function GepCleanInfoCount : Integer;
    function GetEngineVersion: string;
    function GetEngineDate: TDateTime;
    function GepCleanInfo(const i: integer): pCleanInfo;
    procedure ReadEngines;
    procedure Stop;
    function DeleteFile(const FileName: string; const ForceMode: boolean = false): boolean;
    function DeleteRegItem(const RegItem, BackPath: string; const BackReg: boolean = false): boolean;
    function KillProcess(const ProcName, AddStr: string): boolean; overload;
    function KillProcess(const ProcID: Cardinal): boolean; overload;
    procedure Detect;
    procedure Clean(const Engine: TList = nil; const ForceMode: boolean = false; const RetryTimes: Byte = 2);
    procedure GetExistObjectList(const Engine:pCleanInfo; List: TStrings);
    property EngineCount: Integer read GepCleanInfoCount;
    property Engine[const i: integer] : pCleanInfo read GepCleanInfo;
    property EngineVersion: string read GetEngineVersion;
    property EngineDate: TDateTime read GetEngineDate;
  end;


implementation

end.
